<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>拡張</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>%1 のみ</translation>
    </message>
</context>
</TS>